# Contributions to `meteocatpy`

## Owners

- Figorr [GitLab](https://gitlab.com/figorr) [GitHub](https://github.com/figorr)

## Maintainers

- Figorr [GitLab](https://gitlab.com/figorr) [GitHub](https://github.com/figorr)

## Contributors

